package
Version:
v0.0.0-...-8bb53dc
Opens a new window with list of versions in this module.
Published: Mar 14, 2019
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Response struct {
User User `json:"UserData"`
}
Response is a model
Service is a service
NewService returns a new service
GetUser gets the user for the account
type User struct {
Balance string `json:"balance"`
}
User is the model for a user
Source Files
¶
Click to show internal directories.
Click to hide internal directories.