Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuthTokenResponse ¶
type AuthTokenResponse struct {
Token string `json:"token"`
LifetimeSeconds int64 `json:"lifetimeInSeconds"`
}
AuthTokenResponse is the response from a generate auth token request
type CheckoutTokenResponse ¶
type CheckoutTokenResponse struct {
Token string `json:"token"`
Description string `json:"description"`
}
CheckoutTokenResponse is the response from a create checkout token request
type Service ¶
Service is a service
func NewService ¶
func (Service) CreateCheckoutToken ¶
func (s Service) CreateCheckoutToken(phoneNumber string) (*CheckoutTokenResponse, error)
func (Service) GenerateAuthToken ¶
func (s Service) GenerateAuthToken() (*AuthTokenResponse, error)
Click to show internal directories.
Click to hide internal directories.